@@ -4,9 +4,19 @@
 
 ## x: data.frame with RFLP data
 ## distfun: function to compute distance (cf. ?dist)
-RFLPdist <- function(x, distfun = dist, nrBands){
+RFLPdist <- function(x, distfun = dist, nrBands, LOD = 0){
     stopifnot(is.data.frame(x))
     stopifnot(is.function(distfun))
+    if(!missing(nrBands)){
+        if(nrBands <= 0)
+            stop("'nrBands' has to be a positive interger!")
+    }
+    if(LOD < 0)
+        stop("'LOD' has to be non-negative!")
+
+    if(LOD > 0){
+        x <- x[x$MW >= LOD,]
+    }
 
     x1 <- split(x, x$Sample)
     nrbands <- sort(unique(sapply(x1, nrow)))
